@@ -50,7 +50,7 @@ class SignedRequestFactory(object):
     def build_request_url(self, url, headers):
         url = self._build_client_url(url)
         if self.should_data_be_sent_on_querystring():
-            url += "&{0}".format(urlencode(self.raw_data))
+            url += "&{0}".format(urlencode(self.raw_data, doseq=True))
         return self._build_signed_url(url, headers)
 
     def _build_signed_url(self, url, headers):
